@@ -49,14 +49,14 @@ fshift.source_spct <-
         spct = q2e(x, action = "replace"),
         range = range,
         f = f,
-        var.name = "s.e.irrad"
+        col.names = "s.e.irrad"
       ))
     } else if (unit.out %in% c("photon", "quantum")) {
       return(fshift_spct(
         spct = e2q(x, action = "replace"),
         range = range,
         f = f,
-        var.name = "s.q.irrad"
+        col.names = "s.q.irrad"
       ))
     } else {
       stop("'unit.out ", unit.out, " is unknown")
@@ -79,7 +79,7 @@ fshift.response_spct <-
         spct = q2e(x, action = "replace"),
         range = range,
         f = f,
-        var.name = "s.e.response",
+        col.names = "s.e.response",
         ...
       ))
     } else if (unit.out %in% c("photon", "quantum")) {
@@ -87,7 +87,7 @@ fshift.response_spct <-
         spct = e2q(x, action = "replace"),
         range = range,
         f = f,
-        var.name = "s.q.response",
+        col.names = "s.q.response",
         ...
       ))
     } else {
@@ -111,13 +111,13 @@ fshift.filter_spct <- function(x,
     return(fshift_spct(spct = A2T(x, action = "replace"),
                        range = range,
                        f = f,
-                       var.name = "Tfr",
+                       col.names = "Tfr",
                        ...))
   } else if (qty.out == "absorbance") {
     return(fshift_spct(spct = T2A(x, action = "replace"),
                        range = range,
                        f = f,
-                       var.name = "A",
+                       col.names = "A",
                        ...))
   } else {
     stop("'qty.out ", qty.out, " is unknown")
@@ -136,7 +136,7 @@ fshift.reflector_spct <- function(x,
   return(fshift_spct(spct = x,
                      range = range,
                      f = f,
-                     var.name = "Rfr",
+                     col.names = "Rfr",
                      ...))
 }
 
@@ -159,6 +159,59 @@ fshift.source_mspct <-
             ...)
   }
 
+#' @describeIn fshift
+#'
+#' @export
+#'
+fshift.raw_spct <- function(x,
+                            range = c(min(x), min(x) + 10),
+                            f = "mean",
+                            qty.out = NULL,
+                            ...) {
+  return(fshift_spct(spct = x,
+                     range = range,
+                     f = f,
+                     col.names = grep("^counts", names(x), value = TRUE),
+                     ...))
+}
+
+#' @describeIn fshift
+#'
+#' @export
+#'
+fshift.cps_spct <- function(x,
+                            range = c(min(x), min(x) + 10),
+                            f = "mean",
+                            qty.out = NULL,
+                            ...) {
+  return(fshift_spct(spct = x,
+                     range = range,
+                     f = f,
+                     col.names = grep("^cps", names(x), value = TRUE),
+                     ...))
+}
+
+#' @describeIn fshift
+#'
+#' @param col.names character vector containing the names of columns or
+#'   variables to which to apply the scale shift.
+#'
+#' @export
+#'
+fshift.generic_spct <- function(x,
+                                range = c(min(x), min(x) + 10),
+                                f = "mean",
+                                col.names,
+                                ...) {
+  return(fshift_spct(spct = x,
+                     range = range,
+                     f = f,
+                     col.names = col.names,
+                     ...))
+}
+
+# Collections of spectra --------------------------------------------------
+
 #' @describeIn fshift
 #'
 #' @export
@@ -215,6 +268,58 @@ fshift.reflector_mspct <-
             ...)
   }
 
+#' @describeIn fshift
+#'
+#' @export
+#'
+fshift.raw_mspct <-
+  function(x,
+           range = c(min(x), min(x) + 10),
+           f = "min",
+           ...) {
+    msmsply(x,
+            fshift,
+            range = range,
+            f = f,
+            ...)
+  }
+
+#' @describeIn fshift
+#'
+#' @export
+#'
+fshift.cps_mspct <-
+  function(x,
+           range = c(min(x), min(x) + 10),
+           f = "min",
+           ...) {
+    msmsply(x,
+            fshift,
+            range = range,
+            f = f,
+            ...)
+  }
+
+#' @describeIn fshift
+#'
+#' @export
+#'
+fshift.generic_mspct <-
+  function(x,
+           range = c(min(x), min(x) + 10),
+           f = "min",
+           col.names,
+           ...) {
+    msmsply(x,
+            fshift,
+            range = range,
+            f = f,
+            col.names = col.names,
+            ...)
+  }
+
+
+# PRIVATE -----------------------------------------------------------------
 
 #' fshift a spectrum
 #'
@@ -224,7 +329,7 @@ fshift.reflector_mspct <-
 #' @param spct generic_spct The spectrum to be normalized
 #' @param range an R object on which range() returns a vector of length 2, with
 #'   min annd max wavelengths (nm)
-#' @param var.name character The name of the variable to fscale
+#' @param col.names character The name of the variable to fscale
 #' @param f function A summary function to be applied to \code{spct}
 #' @param ... other arguments passed to f()
 #'
@@ -232,7 +337,7 @@ fshift.reflector_mspct <-
 #'
 #' @keywords internal
 #'
-fshift_spct <- function(spct, range, var.name, f, ...) {
+fshift_spct <- function(spct, range, col.names, f, ...) {
   if (is.null(range) ||
       (!is.null(range) && max(range) < min(spct)) ||
       (!is.null(range) && min(range) < min(spct)) ) {
@@ -240,31 +345,32 @@ fshift_spct <- function(spct, range, var.name, f, ...) {
       return(spct)
   }
   tmp.spct <- trim_spct(spct, range, byref = FALSE)
-  tmp.spct <- tmp.spct[, c("w.length", var.name)]
-  # rescaling needed
-  if (!is.null(f)) {
-    if (is.character(f)) {
-      if (f %in% c("mean", "average")) {
-        summary.value <- average_spct(tmp.spct)
-      } else if (f %in% c("min", "minimum")) {
-        summary.value <- min(tmp.spct[[var.name]])
-      } else if (f %in% c("max", "maximum")) {
-        summary.value <- max(tmp.spct[[var.name]])
+  for (col in col.names) {
+    # shifting needed
+    if (!is.null(f)) {
+      if (is.character(f)) {
+        if (f %in% c("mean", "average")) {
+          summary.value <- average_spct(tmp.spct[, c("w.length", col)])
+        } else if (f %in% c("min", "minimum")) {
+          summary.value <- min(tmp.spct[[col]])
+        } else if (f %in% c("max", "maximum")) {
+          summary.value <- max(tmp.spct[[col]])
+        } else {
+          warning("Invalid character '", f, "'value in 'f'")
+          summary.value <- NA_real_
+        }
+      } else if (is.function(f)) {
+        summary.value <- f(tmp.spct[, c("w.length", col)], ...)
+        f <- "a user supplied R function"
       } else {
-        warning("Invalid character '", f, "'value in 'f'")
-        summary.value <- NA_real_
+        stop("'f' should be a function name or character")
       }
-    } else if (is.function(f)) {
-      summary.value <- f(tmp.spct, ...)
-      f <- "a user supplied R function"
     } else {
-      stop("'f' should be a function name or character")
+      summary.value <- 0
+      # implemented in this way to ensure that all returned
+      # values folow the same copy/reference semantics
     }
-  } else {
-    summary.value <- 0
-    # implemented in this way to ensure that all returned
-    # values folow the same copy/reference semantics
+    spct[[col]] <- spct[[col]] - summary.value
   }
-  spct[[var.name]] <- spct[[var.name]] - summary.value
   spct
 }
