@@ -4,8 +4,10 @@
 #' spectral data stored in a \code{reflector_spct} or in an \code{object_spct}.
 #'
 #' @param spct an R object
-#' @param w.band waveband or list of waveband objects The waveband(s) determine
-#'   the region(s) of the spectrum that are summarized.
+#' @param w.band waveband or list of waveband objects or a numeric vector of
+#'   length two. The waveband(s) determine the region(s) of the spectrum that
+#'   are summarized. If a numeric range is supplied a waveband object is
+#'   constructed on the fly from it.
 #' @param quantity character
 #' @param wb.trim logical Flag telling if wavebands crossing spectral data boundaries
 #'   are trimmed or ignored
@@ -70,7 +72,10 @@ reflectance.object_spct <-
 #' reflectance spectrum.
 #'
 #' @param spct an object of class generic_spct"
-#' @param w.band list of waveband definitions created with new_waveband()
+#' @param w.band waveband or list of waveband objects or a numeric vector of
+#'   length two. The waveband(s) determine the region(s) of the spectrum that
+#'   are summarized. If a numeric range is supplied a waveband object is
+#'   constructed on the fly from it.
 #' @param quantity character string
 #' @param wb.trim logical if TRUE wavebands crossing spectral data boundaries
 #'   are trimmed, if FALSE, they are discarded
@@ -82,6 +87,12 @@ reflectance.object_spct <-
 #'
 reflectance_spct <-
   function(spct, w.band, quantity, wb.trim, use.hinges){
+    num.spectra <- getMultipleWl(spct)
+    if (num.spectra != 1) {
+      warning("Skipping reflectance calculation as object contains ",
+              num.spectra, " spectra")
+      return(NA_real_)
+    }
     Rfr.type <- getRfrType(spct)
     if (is.object_spct(spct)) {
       spct <- as.reflector_spct(spct)
@@ -91,6 +102,9 @@ reflectance_spct <-
     if (is.null(w.band)) {
       w.band <- waveband(spct)
     }
+    if (is.numeric(w.band)) {
+      w.band <- waveband(w.band)
+    }
     if (is.waveband(w.band)) {
       # if the argument is a single w.band, we enclose it in a list
       # so that the for loop works as expected.This is a bit of a
